@@ -332,7 +332,7 @@ class ModelAPI(API):
 			if hasattr(qs.query, 'select_fields'):
 				fields = [f.name for f in qs.query.select_fields] + list(qs.query.aggregate_select.keys())
 			else:
-				fields = [f.name for f in qs.query.select] + list(qs.query.aggregate_select.keys())
+				fields = [f.field.name for f in qs.query.select] + list(qs.query.aggregate_select.keys())
 			
 			if not any(fields):
 				fields = [f.name for f in self.model._meta.local_fields]
